@@ -39,9 +39,9 @@
 KOrganizerApp::KOrganizerApp(int &argc, char **argv[])
     : KontactInterface::PimUniqueApplication(argc, argv)
 {
-    QString prodId = QStringLiteral("-//K Desktop Environment//NONSGML KOrganizer %1//EN");
+    const QString prodId = QStringLiteral("-//K Desktop Environment//NONSGML KOrganizer %1//EN");
     KCalendarCore::CalFormat::setApplication(QStringLiteral("KOrganizer"),
-                                        prodId.arg(QStringLiteral(KORGANIZER_VERSION)));
+                                             prodId.arg(QStringLiteral(KORGANIZER_VERSION)));
 }
 
 KOrganizerApp::~KOrganizerApp()
@@ -94,7 +94,6 @@ int KOrganizerApp::activate(const QStringList &args, const QString &workingDir)
             korg->actionManager()->importURL(QUrl::fromUserInput(url), true);
         }
     } else {
-        // Q_FOREACH, since range-based loops might detach Qt container (QStringList)
         const auto lst = parser.positionalArguments();
         for (const QString &url : lst) {
             korg->actionManager()->importCalendar(QUrl::fromUserInput(url));
